Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(15)

Unified Diff: chrome/android/java/src/org/chromium/chrome/browser/webapps/WebApkInstaller.java

Issue 2184913005: Add calls to the server to request WebAPK updates. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: WebAPK no longer owns a ManifestUpgradeDetector and rebase on "worker thread" CL. Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/android/java/src/org/chromium/chrome/browser/webapps/WebApkInstaller.java
diff --git a/chrome/android/java/src/org/chromium/chrome/browser/webapps/WebApkInstaller.java b/chrome/android/java/src/org/chromium/chrome/browser/webapps/WebApkInstaller.java
index fd0629e9ad4b94a5327049be5bd2eb96efba4fad..55a9252e042dc8ab8e1af0541e8e87d9e12287f5 100644
--- a/chrome/android/java/src/org/chromium/chrome/browser/webapps/WebApkInstaller.java
+++ b/chrome/android/java/src/org/chromium/chrome/browser/webapps/WebApkInstaller.java
@@ -18,7 +18,7 @@ import java.io.File;
/**
* Java counterpart to webapk_installer.h
* Contains functionality to install WebAPKs.
*/
public class WebApkInstaller {
private static final String TAG = "WebApkInstaller";
@@ -53,6 +53,18 @@ public class WebApkInstaller {
}
/**
+ * Updates a WebAPK.
+ * @param filePath File to update.
+ * @param packageName Package name to update WebAPK at.
+ * @return True if the update was started. A "true" return value does not guarantee that the
+ * update succeeds.
+ */
+ @CalledByNative
+ private static boolean updateAsyncFromNative(String filePath, String packageName) {
+ return false;
Yaron 2016/08/12 21:16:16 i'm confused - why is this disabled? enough moving
Xi Han 2016/08/15 21:38:44 It returns false since I didn't add a logic to upd
Yaron 2016/08/16 00:32:03 you have to trigger the install the same way as in
Xi Han 2016/08/16 14:08:14 Acknowledged. Since this isn't the focus of this C
+ }
+
+ /**
* Returns whether the user has enabled installing apps from sources other than the Google Play
* Store.
*/
@@ -18,7 +18,7 @@ import java.io.File;
/**
* Java counterpart to webapk_installer.h
- * Contains functionality to install WebAPKs.
+ * Contains functionality to install / update WebAPKs.
*/
public class WebApkInstaller {

Powered by Google App Engine
This is Rietveld 408576698